**aritimetica** é um simples pacote de operações aritméticas em Python.

## Funções

* `soma (valorx,valory)` - Recebe dois valores e retorna valor da soma

* `subtracao (valorx,valory)` - Recebe dois valores e retorna valor da subtração

* `divisao (valorx,valory)` - Recebe dois valores e retorna valor divisão

* `multiplicacao (valorx,valory)` - Recebe dois valores e retorna valor da multiplicação


